@@ -18,7 +18,7 @@
 #include "vtkConfigure.h"
 
 /* Use the libharu library configured for VTK.  */
-#define VTK_USE_SYSTEM_LIBHARU
+/* #undef VTK_USE_SYSTEM_LIBHARU */
 
 #ifdef VTK_USE_SYSTEM_LIBHARU
 /* Defined if using external libhary, and the library is a shared lib. */
