@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkAssemblyNode extends vtkObject
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -25,7 +25,7 @@ public class vtkAssemblyNode extends vtkObject
 
     if (temp == 0) return null;
     return (vtkProp)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetMatrix_4(vtkMatrix4x4 id0);
   public void SetMatrix(vtkMatrix4x4 id0)
@@ -37,7 +37,7 @@ public class vtkAssemblyNode extends vtkObject
 
     if (temp == 0) return null;
     return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native int GetMTime_6();
   public int GetMTime()
